package com.plannaplan.repositories;

import java.util.List;
import java.util.Optional;

import com.plannaplan.entities.Groups;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

/**
 *  GroupRepository.find:
 *      Return list of:
 *      SELECT * FROM Groups WHERE time = i AND room = j AND capacity = k .
 * 
 *      Where i, j, k, ?1, ?2, ?3 are equale to variables. 
 * 
 *  GroupRepository.getByCourse:
 *      Return list of:
 *      SELECT * FROM Groups WHERE course_id = i .
 * 
 *      Where i, ?1 are equale to variables. 
 */
@Repository
public interface GroupRepository extends JpaRepository<Groups, Long> {
    @Query("FROM Groups WHERE time = ?1 AND room = ?2 AND capacity = ?3")
    Optional<Groups> find(@Param("time") int time, @Param("room") String room, @Param("capacity") int capacity);

    @Query("FROM Groups WHERE course_id = ?1")
    List<Groups> getByCourse(@Param("id") Long id);

}